run

Function run 

pub fn run(cli_args: Arguments) -> Result<RslOutput>
Runs frs rsl.

Returns the lint violations for the supplied files.

Errors

Returns an error when the arguments are invalid or a source file cannot be read or parsed.